@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -201,6 +201,7 @@ ServiceName = Literal[
     "glacier",
     "globalaccelerator",
     "glue",
+    "grafana",
     "greengrass",
     "greengrassv2",
     "groundstation",
@@ -285,6 +286,7 @@ ServiceName = Literal[
     "opsworkscm",
     "organizations",
     "outposts",
+    "panorama",
     "personalize",
     "personalize-events",
     "personalize-runtime",
