@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Mapping, Sequence, Union
+from typing import Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     ActionStatusType,
@@ -31,7 +31,7 @@ from .literals import (
     TimeUnitType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -704,7 +704,7 @@ ResponseMetadataTypeDef = TypedDict(
         "RequestId": str,
         "HostId": str,
         "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
+        "HTTPHeaders": Dict[str, str],
         "RetryAttempts": int,
     },
 )
